// 常量
const ENCODE = window.encodeURIComponent;
const DECODE = window.decodeURIComponent;

let zerofill = val => val >= 10 ? val : '0' + val;


// 工具类
var Utils = {

	encode: ENCODE,
	decode: DECODE,

	// json 转 url 参数
	jsonToParam(json){
		var arr = [], value;

		Object.keys(json).forEach((key)=> {
			value = json[key] == null ? '' : json[key];
			arr[arr.length] = `${ENCODE(key)}=${ENCODE(value)}`;
		});

		return arr.join('&');
	},

	// 延时队列
	delayQueue(fn, duration = 20) {
		var that = this;
		var queue = that.delayQueue;
		queue.list = queue.list || [];
		fn && queue.list.push(fn) && (fn.duration = duration);
		if (!queue.timer && queue.list.length) {
			var _fn = queue.list.shift();
			queue.timer = setTimeout(() => {
				_fn();
				queue.call(that, queue.timer = null);
			}, _fn.duration);
		}
	},

	// 时间格式化
	dateTimeFormatter(time, type){

		if (time == 'Invalid Date') {
			return time;
		}

		if (typeof time == 'string') {
			time = time.replace(/-/g, '/');
		}

		let date = new Date(time);

		let year = date.getFullYear();
		let month = date.getMonth() + 1;
		let day = date.getDate();
		let hours = date.getHours();
		let minutes = date.getMinutes();
		let second = date.getSeconds();

		switch (type) {
			case 0: // 01-05
				return `${zerofill(month)}-${zerofill(day)}`;
			case 1: // 11:12
				return `${zerofill(hours)}：${zerofill(minutes)}`;
			case 2: // 2015-01-05
				return `${year}-${zerofill(month)}-${zerofill(day)}`;
			case 3: // 2015-01-05 11:12
				return `${year}-${zerofill(month)}-${zerofill(day)}  ${zerofill(hours)}:${zerofill(minutes)}`;
			case 4: // 2015年01月05日
				return `${year}年${zerofill(month)}月${zerofill(day)}日`;
			default: // 2015-01-05 11:12:13
				return `${year}-${zerofill(month)}-${zerofill(day)}  ${zerofill(hours)}:${zerofill(minutes)}:${zerofill(second)}`;
		}

	},


	// 判断对象是否为空 {}、[]、空构造函数 都会返回 true
	isEmptyObject: function (obj) {
		var name;
		// 不可枚举属性的实例属性不会出现在 for-in 循环中
		for (name in obj) {
			return false;
		}
		return true;
	},

	// 冻结对象，防止对象属性值被更改
	freeze: (obj) => {
		const _freeze = (obj) => {
			Object.freeze(obj);
			Object.keys(obj).forEach((key, value) => {
				if (typeof obj[key] === 'object') {
					_freeze(obj[key]);
				}
			});
		};
		_freeze(obj);
		return obj;
	}


};


export { Utils };