import React, { Component } from 'react';
import { browserHistory } from 'react-router';
import moment from 'moment';
import classNames from 'classnames';
import { Button, Row, Col, Spin } from 'antd';
import { VENDOR_STATE, COMPANY_TYPE, CREDENTIALS_TYPE, CURRENCY_TYPE } from 'constants/enum';
import { Utils } from 'assets/utils';

const emptyText = '----';
const yesOrNo = (yes) => yes == 1 ? '是' : '否';
const hasOrNo = (has) => has == 1 ? '有' : '没有';
const formatDate = (date, format = 'YYYY年MM月DD日') => date ? moment(date).format(format) : '';
const dataRange = (range = [], format = 'YYYY年MM月DD日', connect = ' 至 ') => {
	return (formatDate(range[0], format) || emptyText) + connect + (formatDate(range[1], format) || emptyText);
};

const showAttachments = (attachments, attachmentType) => {

	if (Utils.isEmptyObject(attachments)) {
		return emptyText;
	}

	return !attachments[attachmentType] ? '' : attachments[attachmentType].map((item, index)=> {
		return <p key={index}><a href="" target="_blank">{item.fileName}</a></p>;
	});
};

const BoxTable = ({ title = '', colSize = 2, className='box-rows', data = [] }) => {
	const rowCount = Math.ceil(data.length / colSize);
	return (
		<div className="box-table">
			{
				title ?
					<div className="box-title">
						<Row>
							<Col>{title}</Col>
						</Row>
					</div>
					: ''
			}
			<div className={className}>
				{
					(function () {
						let n = 0;
						let rows = [];
						for (let i = 0; i < rowCount && n < data.length; i++) {
							let cols = [];
							for (let j = 0; j < colSize && n < data.length; j++, n++) {
								cols.push(<Col span={5} key={'row'+i+'-col'+j+'-0'}>{ data[n][0] }：</Col>);
								cols.push(<Col span={7} key={'row'+i+'-col'+j+'-1'}>{ data[n][1] || emptyText }</Col>);
							}
							rows.push(<Row key={'row'+i}>{ cols }</Row>);
						}
						return rows;
					})()
				}
			</div>
		</div>
	);
};

class Detail extends Component {

	constructor(props) {
		super(props);
	}

	componentDidMount() {
	}

	handleHref(ev) {
		ev.preventDefault();

		// TODO..  如果登入超时，弹出登入框
		const path = '/home/vendor/edit';

		browserHistory.push(path);
	}

	render() {
		const data = this.props.vendorData;

		const isFetching = this.props.isFetching;

		let btnStyle = {
			width  : 160, height: 36, position: 'absolute', top: 10, right: 60,
			display: this.props.isShow ? "none" : "block"
		};

		let grayClass = classNames('box-rows', {
			'gray': !data.created
		});

		return (
			<Spin spinning={isFetching}>

				<div>
					<BoxTable
						colSize="1"
						className={grayClass}
						data={[
					        ['供应商编号', data.vendorNo],
					        ['审核状态', VENDOR_STATE[data.state]],
					        ['审核时间', formatDate(data.updated)]
					    ]}
					/>
					{
						!isFetching &&
						<Button type="primary" onClick={this.handleHref.bind(this)} style={btnStyle}>
							编辑信息
						</Button>
					}
				</div>

				<BoxTable
					title="基本信息"
					className={grayClass}
					data={[
					        ['供应商名称', data.vendorNameCn],
					        ['公司类型', COMPANY_TYPE[data.companyType]],
					        ['公司成立时间', formatDate(data.foundDateMillis)],
					        ['营业期限', dataRange([data.bizStartDateMillis, data.bizEndDateMillis])],
					        ['年营业额', data.yearlyTurnover ? `${data.yearlyTurnover} 万元` : '']
					    ]}
				/>

				<BoxTable
					title="证件信息"
					className={grayClass}
					data={[
					        ['是否三证合一', yesOrNo(data.threeInOneFlag)],
					        ['统一社会信用代码', data.uniformCreditNo],
					        ['增值税一般纳税人资格', hasOrNo(data.vatFlag)],
					        ['营业执照编号', data.licenceNo],
					        ['法定代表人', data.legalAgent],
					        ['证件类型', CREDENTIALS_TYPE[data.credentialsType]],
					        ['证件号码', data.credentialsNo]
					    ]}
				/>

				<BoxTable
					title="运营能力"
					className={grayClass}
					data={[
					        ['是否有独立电商团队', yesOrNo(data.eTeamFlag)],
					        ['团队人数', data.eTeamSize ? `${data.eTeamSize} 人` : ''],
					        ['是否有独立运营网站', hasOrNo(data.ownWebsiteFlag)],
					        ['是否有实体店', hasOrNo(data.physicalStoreFlag)],
					        ['总店地址', data.headStoreAddr],
					        ['实体店经营年限', data.storeDuration ? `经营了 ${data.storeDuration} 年` : ''],
					        ['是否与其他平台合作', yesOrNo(data.otherCoopFlag)],
					        ['合作平台名称', data.coopPltName],
					        ['月均发单量', data.monthSaleAmt]
					    ]}
				/>

				<BoxTable
					title="服务能力"
					className={grayClass}
					data={[
					        ['是否可以配送', yesOrNo(data.shipFlag)],
					        ['是否有合作的物流', yesOrNo(data.coopLogisticsFlag)],
					        ['合作的物流名称', data.coopLogisticsName],
					        ['是否自有仓库', hasOrNo(data.ownWarehouseFlag)],
					        ['仓库面积', data.ownWarehouseArea ? `${data.ownWarehouseArea} 平方米` : ''],
					        ['节假日是否发货', yesOrNo(data.holidayShipFlag)],
					        ['每日发货次数', data.dailyShipTimes ? `${data.dailyShipTimes} 次` : ''],
					        ['客服人数', data.custServiceQty ? `${data.custServiceQty} 人` : ''],
					        ['热线电话', data.hotline],
					        ['工作日热线电话服务时间', dataRange([data.hotlineWorkdayStartMillis, data.hotlineWorkdayEndMillis], 'hh:mm')],
					        ['周末及法定节假日热线电话服务时间', dataRange([data.hotlineWeekendStartMillis, data.hotlineWeekendEndMillis], 'hh:mm')]
					    ]}
				/>

				<BoxTable
					title="联系人"
					className={grayClass}
					data={[
					        ['业务联系人姓名', data.bizConName],
					        ['业务联系人固定电话', data.bizConFixedPhone],
					        ['业务联系人手机号', data.bizConMobilePhone],
					        ['业务联系人邮箱', data.bizConEmail],
					        ['财务联系人姓名', data.finConName],
					        ['财务联系人固定电话', data.finConFixedPhone],
					        ['财务联系人手机号', data.finConMobilePhone],
					        ['财务联系人邮箱', data.finConEmail],
					        ['客服联系人姓名', data.custConName],
					        ['客服联系人固定电话', data.custConFixedPhone],
					        ['客服联系人手机号', data.custConMobilePhone],
					        ['客服联系人邮箱', data.custConEmail]
					    ]}
				/>

				<BoxTable
					title="财务清算"
					className={grayClass}
					data={[
					        ['收款账号名称', data.bankAcctName],
					        ['收款账号', data.bankAcctNo],
					        ['开户银行名称', data.bankName],
					        ['联行行号', data.bankCode],
					        ['银行所在地', data.bankLocCity],
					        ['清算币种', CURRENCY_TYPE[data.settleCurrency]],
					        ['是否需要增值税专用发票', yesOrNo(data.vatInvoiceFlag)],
					        ['纳税人名称', data.taxPayerName],
					        ['纳税人地址', data.taxAddr],
					        ['纳税人识别号', data.taxPayerNo],
					        ['接受发票的地址', data.acptInvoiceAddr],
					        ['增值税发票银行开户行名称', data.acptBankName],
					        ['增值税发票银行开户行账号', data.acptBankAcctNo]
					    ]}
				/>

				<BoxTable
					title="附件"
					className={grayClass}
					data={[
					        ['营业执照', showAttachments(data.attachments,1)],
							['现金流量表', showAttachments(data.attachments,2)],
							['法定代表人证件', showAttachments(data.attachments,3)],
							['品牌授权委托书', showAttachments(data.attachments,4)],
							['资产负债表', showAttachments(data.attachments,5)],
							['损益表或验资报告', showAttachments(data.attachments,6)],
							['仓库照片', showAttachments(data.attachments,7)],
							['办公地址照片', showAttachments(data.attachments,8)],
							['其他', showAttachments(data.attachments,9)]
					    ]}
				/>


			</Spin>
		)
	}
}

export default Detail;
