import React, { Component } from 'react';
import { connect } from 'react-redux';
import { Link, browserHistory } from 'react-router';


import { Form, Icon, Input, Button, Row, Col, Modal } from 'antd';
const FormItem = Form.Item;

import userService from 'services/userService';
import { saveUser } from 'actions/userAction';

class Login extends Component {

	constructor(props) {
		super(props);

		this.state = {
			loading: false
		}
	}

	componentDidMount() {
		this.calculateHeight();
		window.addEventListener('resize', this.calculateHeight.bind(this), false);
	}

	//计算高度
	calculateHeight() {
		//截流
		clearTimeout(this.calculateTimer);
		this.calculateTimer = setTimeout(() => {
			if (document.getElementsByClassName('login-form')[0]) {
				document.getElementsByClassName('login-form')[0].style.minHeight = document.documentElement.clientHeight - 250 - 70 + 'px';
			}
		}, 500);
	}

	handleSubmit(e) {
		e.preventDefault();

		this.props.form.validateFields((err, values) => {
			if (!err) {
				this.setState({ loading: true });

				userService.login(values).then((data)=> {

					this.setState({ loading: false });

					this.props.dispatch(saveUser({ vendorNo: data.data, loginName: values.loginName }));

					localStorage.setItem('vendorNo', data.data);
					localStorage.setItem('loginName', values.loginName);

					if (this.props.location.query.next) {
						browserHistory.replace(this.props.location.query.next);
					} else {
						browserHistory.replace('/home');
					}

				}).catch((err)=> {
					console.log(err);
					Modal.error({ title: err.statusText, onOk: ()=> { this.setState({ loading: false }); } });
				});
			}
		});

	}

	getCaptcha() {
		this.refs['Captcha'].src = '/api/sp/usr/captcha' + '?r=' + new Date().getTime();
	}

	render() {
		const { getFieldDecorator } = this.props.form;

		return (
			<div id="Login">
				<style>
					{"body { background-color: #191919; }"}
				</style>
				<header>
					<h1>疾风商城供应管理系统</h1>
					<h3>为客户提供高效、专业的服务</h3>
				</header>
				<section>
					<Form onSubmit={this.handleSubmit.bind(this)} className="login-form">
						<FormItem>
							{
								getFieldDecorator('loginName', {
									rules: [
										{
											required: true, message: '请输入你的用户名!'
										},
										{
											type   : 'string',
											max    : 32,
											message: '用户名长度不超过 32'
										}
									]
								})(
									<Input addonBefore={<Icon type="user" />} placeholder="请输入你的用户名"/>
								)
							}
						</FormItem>
						<FormItem>
							{
								getFieldDecorator('loginPassword', {
									rules: [
										{
											required: true, message: '请输入密码!'
										},
										{
											type   : 'string',
											max    : 32,
											message: '密码长度不超过 32'
										}
									]
								})(
									<Input addonBefore={<Icon type="lock" />} type="password" placeholder="请输入你的密码"/>
								)
							}
						</FormItem>

						<FormItem>
							<Row gutter={8}>
								<Col span={7}>
									{getFieldDecorator('captchaText', {
										rules: [
											{
												required: true, message: '请输入验证码!'
											},
											{
												type   : 'string',
												max    : 4,
												message: '验证码长度不超过 4'
											}
										]
									})(
										<Input size="large"/>
									)}
								</Col>
								<Col span={10}>
									<img src="/api/sp/usr/captcha" style={{width: 140,height:40}} ref="Captcha"/>
								</Col>
								<Col span={7}>
									<Button size="large" onClick={this.getCaptcha.bind(this)}>刷新验证码</Button>
								</Col>
							</Row>
						</FormItem>

						<FormItem>

							<Button type="primary" htmlType="submit" className="login-form-button" loading={this.state.loading}>
								立即登入
							</Button>
							<div style={{textAlign:'right',fontSize:'14px',cursor:'pointer'}} onClick={()=>{
								Modal.info({
									title: '若您忘记密码，请联系XXX，电话021-6666666。'
								});
							}}>
								<span>忘记密码？</span>
							</div>

						</FormItem>
					</Form>
				</section>

			</div>
		)
	}
}

export default connect()(Form.create()(Login));
