import React, { Component } from 'react';
import { connect } from 'react-redux';
import {
	Form,
	Input,
	Select,
	DatePicker,
	TimePicker,
	Button,
	Switch,
	InputNumber,
	Modal,
	Row,
	Col,
	Upload,
	Icon
} from 'antd';

const FormItem = Form.Item;
const Option = Select.Option;
const RangePicker = DatePicker.RangePicker;
import moment from 'moment';
import RowTitle from 'components/Vendor/RowTitle';
import { saveVendor } from 'actions/vendorAction';
import { COMPANY_TYPE, CREDENTIALS_TYPE, CURRENCY_TYPE } from 'constants/enum';
import vendorService from 'services/vendorService';
import { VendorForm } from 'services/formData/vendorForm';
import { Utils } from 'assets/utils';

// TODO.. 样式导入是否要优化
import 'components/Vendor/vendor.scss';


const CreateOption = (obj) => {

	return Object.keys(obj).map((key) => {

		return (
			<Option value={key} key={key}>{obj[key]}</Option>
		);
	});

};

class Edit extends Component {

	constructor(props) {

		super(props);

		this.state = {
			confirmDisabled            : false,
			isUniformCreditNoRequired  : false,
			isOwnWarehouseFlagRequired : false,
			isCoopLogisticsFlagRequired: false,
			isETeamSizeDisabled        : true,
			isPhysicalStoreFlagDisabled: true,
			isOtherCoopFlagDisabled    : true,
			fileListLicence            : [],
			fileListCashFlowStatement  : [],
			fileListLegalCert          : [],
			fileListBrandAuthor        : [],
			fileListBalanceSheet       : [],
			fileListIncomeStatement    : [],
			fileListWarehousePhotos    : [],
			fileListOfficeAddressPhoto : [],
			fileListOthers             : []
		};

	}

	componentDidMount() {
		if (!Utils.isEmptyObject(this.props.vendorData)) {
			this.setRequired(this.props.vendorData);
			this.setDisabled(this.props.vendorData);
			this.setFileList(this.props.vendorData);
		}
	}

	componentWillUnmount() {
		// TODO.. 销毁页面中的 Modal，调整ui
		console.log('即将销毁');
	}

	componentWillReceiveProps(nextProps) {
		if (nextProps.vendorData && nextProps.vendorData.threeInOneFlag != (this.props.vendorData && this.props.vendorData.threeInOneFlag )) {
			this.setRequired(nextProps.vendorData);
			this.setDisabled(nextProps.vendorData);
			this.setFileList(nextProps.vendorData);
		}
	}

	setRequired(vendorData) {
		this.setState({
			isUniformCreditNoRequired  : vendorData.threeInOneFlag == 1,
			isCoopLogisticsFlagRequired: vendorData.coopLogisticsFlag == 1,
			isOwnWarehouseFlagRequired : vendorData.ownWarehouseFlag == 1
		});
	}

	setDisabled(vendorData) {

		this.setState({
			isETeamSizeDisabled        : !vendorData.eTeamSize,
			isPhysicalStoreFlagDisabled: !vendorData.headStoreAddr,
			isOtherCoopFlagDisabled    : !vendorData.coopPltName
		});

	}

	setFileList(vendorData) {
		var attachments = vendorData.attachments;

		if (!Utils.isEmptyObject(attachments)) {

			this.setState({
				fileListLicence           : this.uploadDataFormatter(attachments['1']),
				fileListCashFlowStatement : this.uploadDataFormatter(attachments['2']),
				fileListLegalCert         : this.uploadDataFormatter(attachments['3']),
				fileListBrandAuthor       : this.uploadDataFormatter(attachments['4']),
				fileListBalanceSheet      : this.uploadDataFormatter(attachments['5']),
				fileListIncomeStatement   : this.uploadDataFormatter(attachments['6']),
				fileListWarehousePhotos   : this.uploadDataFormatter(attachments['7']),
				fileListOfficeAddressPhoto: this.uploadDataFormatter(attachments['8']),
				fileListOthers            : this.uploadDataFormatter(attachments['9'])
			})

		}

	}

	uploadDataFormatter(attachments) {

		let arr = [];

		if (!attachments) {
			return [];
		}

		for (let i = 0; i < attachments.length; i++) {

			arr.push({
				"uid"           : attachments[i].id || attachments[i].uid,
				"name"          : attachments[i].fileName,
				"url"           : attachments[i].path,
				"attachmentType": attachments[i].attachmentType,
				"fileMd5"       : attachments[i].fileMd5,
				"fileName"      : attachments[i].fileName,
				"path"          : attachments[i].path,
				"fileSize"      : attachments[i].fileSize,
				"fileType"      : attachments[i].fileType
			});
		}

		return arr;
	}

	uploadChange(info, keyName) {
		let fileList = info.fileList;

		fileList = fileList.slice(-5);

		this.setState({ [keyName]: fileList });

	}

	formatForm(formData) {

		const formatDate = (time) => time && new Date(time.toString()).getTime();
		const formatFlag = (flag) => (!(flag === undefined || flag == 0)) ? '1' : '0';
		const formatUpload = (obj, attachmentType)=> {
			var arr = [];

			if (Array.isArray(obj)) {
				return obj;
			}

			for (let i = 0; i < obj.fileList.length; i++) {

				let response = obj.fileList[i].response;

				if (response) {

					let path = response.result.path;

					arr.push({
						"uid"           : path.substring(path.lastIndexOf('/') + 1, path.length).split('.')[0],
						"attachmentType": attachmentType,
						"fileMd5"       : response.result.fileMd5,
						"fileName"      : response.result.fileName,
						"path"          : path,
						"fileSize"      : response.result.size,
						"fileType"      : response.result.fileType
					});

				} else {
					arr.push(obj.fileList[i]);
				}

			}

			return arr;
		};

		formData.vendorNo = this.props.userData.vendorNo;
		formData.state = 2;

		formData.foundDateMillis = formatDate(formData.foundDateMillis);
		formData.bizStartDateMillis = formatDate(formData.bizDateMillis[0]);
		formData.bizEndDateMillis = formatDate(formData.bizDateMillis[1]);
		formData.yearlyTurnover = formData.yearlyTurnover && formData.yearlyTurnover.toFixed(4);
		formData.regCapital = formData.regCapital && formData.regCapital.toFixed(4) - 0;
		formData.threeInOneFlag = formatFlag(formData.threeInOneFlag);
		formData.vatFlag = formatFlag(formData.vatFlag);
		formData.eTeamFlag = formatFlag(formData.eTeamFlag);
		formData.eTeamCapital = formData.eTeamCapital && formData.eTeamCapital.toFixed(4);
		formData.ownWebsiteFlag = formatFlag(formData.ownWebsiteFlag);
		formData.physicalStoreFlag = formatFlag(formData.physicalStoreFlag);
		formData.otherCoopFlag = formatFlag(formData.otherCoopFlag);
		formData.dailySaleAmt = formData.dailySaleAmt === undefined ? 0 : Math.round(formData.dailySaleAmt);
		formData.shipFlag = formatFlag(formData.shipFlag);
		formData.coopLogisticsFlag = formatFlag(formData.coopLogisticsFlag);
		formData.ownWarehouseFlag = formatFlag(formData.ownWarehouseFlag);
		formData.ownWarehouseArea = formData.ownWarehouseArea === undefined ? 0 : formData.ownWarehouseArea;
		formData.holidayShipFlag = formatFlag(formData.holidayShipFlag);
		formData.vatInvoiceFlag = formatFlag(formData.vatInvoiceFlag);
		formData.storeDuration = formData.storeDuration - 0;
		formData.uniformCreditNo = formData.uniformCreditNo.trim();
		formData.hotlineWeekendStartMillis = formatDate(formData.hotlineWeekendStartMillis);
		formData.hotlineWeekendEndMillis = formatDate(formData.hotlineWeekendEndMillis);
		formData.hotlineWorkdayStartMillis = formatDate(formData.hotlineWorkdayStartMillis);
		formData.hotlineWorkdayEndMillis = formatDate(formData.hotlineWorkdayEndMillis);
		formData.uploadLicence = formatUpload(formData.uploadLicence, 1);
		formData.uploadCashFlowStatement = formatUpload(formData.uploadCashFlowStatement, 2);
		formData.uploadLegalCert = formatUpload(formData.uploadLegalCert, 3);
		formData.uploadBrandAuthor = formatUpload(formData.uploadBrandAuthor, 4);
		formData.uploadBalanceSheet = formatUpload(formData.uploadBalanceSheet, 5);
		formData.uploadIncomeStatement = formatUpload(formData.uploadIncomeStatement, 6);
		formData.uploadWarehousePhotos = formatUpload(formData.uploadWarehousePhotos, 7);
		formData.uploadOfficeAddressPhoto = formatUpload(formData.uploadOfficeAddressPhoto, 8);
		formData.uploadOthers = formatUpload(formData.uploadOthers, 9);
		formData.attachments = {
			"1": formData.uploadLicence,
			"2": formData.uploadCashFlowStatement,
			"3": formData.uploadLegalCert,
			"4": formData.uploadBrandAuthor,
			"5": formData.uploadBalanceSheet,
			"6": formData.uploadIncomeStatement,
			"7": formData.uploadWarehousePhotos,
			"8": formData.uploadOfficeAddressPhoto,
			"9": formData.uploadOthers
		};

		return formData;

	}

	handleSubmit(ev) {

		ev.preventDefault();

		this.props.form.validateFields((err, values) => {

			if (!err) {

				var formData = this.formatForm(values);
				// TODO.. 提出 confirm 组件
				Modal.confirm({
					title   : '请仔细核实信息，再确认提交审核。',
					onOk    : ()=> {
						return new Promise((resolve)=> {
							this.editVendor(formData, resolve);
						});
					},
					onCancel: (close)=> {
						if (!this.state.confirmDisabled) {
							close();
						}
					}
				});


			} else {
				Modal.error({ title: '输入信息有误，请检查填写的内容是否符合规范' });
			}

		});

	}

	editVendor(formData, resolve) {

		var no = Utils.isEmptyObject(this.props.vendorData) ? '' : formData.vendorNo;

		this.setState({
			confirmDisabled: true
		});


		vendorService.editVendor(no, formData).then((data)=> {

			Modal.success({
				title: data.msg,
				onOk : ()=> {
					this.setState({
						confirmDisabled: false
					});
				}
			});

			resolve();

			console.log(Object.assign({}, this.props.vendorData, formData));

			this.props.dispatch(saveVendor(Object.assign({}, this.props.vendorData, formData)));

		}).catch((err)=> {

			console.log(err);

			// 出错了
			Modal.error({
				title: err.statusText,
				onOk : ()=> {
					this.setState({
						confirmDisabled: false
					});
				}
			});

			resolve();

		});

	}

	render() {

		const { getFieldDecorator } = this.props.form;
		const data = this.props.vendorData || VendorForm;

		let formItemLayout = {
			labelCol  : { span: 8 },
			wrapperCol: { span: 16 }
		};

		let formItemLayoutDatePicker = {
			labelCol  : { span: 8 },
			wrapperCol: { span: 12 }
		};

		let formItemLayoutNum = {
			labelCol  : { span: 8 },
			wrapperCol: { span: 14 }
		};

		let style = {
			datePicker : { width: "90%" },
			numInput   : { width: "80%" },
			switchWidth: { width: 50 }
		};

		let propsUpload = {
			action      : '/api/sp/fileupload',
			data        : { bizType: 3, no: 6688875 },
			multiple    : true,
			beforeUpload: (file, fileList)=> {
				if (file.size > 1048576) {
					Modal.error({ title: '上传的文件太大了' });
				}
				this.setState({
					upLoading: true
				});
			}
		};


		return (
			<div>
				<Form onSubmit={this.handleSubmit.bind(this)}>

					<RowTitle title="基本信息"/>

					<div className="form-wrap">
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='供应商名称' hasFeedback>
									{
										getFieldDecorator('vendorNameCn', {
											initialValue: data.vendorNameCn,
											rules       : [
												{
													required: true,
													message : '请填写供应商名称'
												},
												{
													type   : 'string',
													max    : 30,
													message: '供应商名称 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入供应商名称"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='公司类型' hasFeedback>
									{
										getFieldDecorator('companyType', {
											[data.companyType ? 'initialValue' : '']: data.companyType,
											rules                                   : [
												{ required: true, message: '请选择公司类型' }
											]
										})(
											<Select placeholder="请选择公司类型">
												{ CreateOption(COMPANY_TYPE) }
											</Select>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutDatePicker} label="公司成立时间" hasFeedback>
									{
										getFieldDecorator('foundDateMillis', {
											[data.foundDateMillis ? 'initialValue' : '']: moment(data.foundDateMillis),
											rules                                       : [{
												type    : 'object',
												required: true,
												message : '请选择日期'
											}]
										})(
											<DatePicker style={style.datePicker}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutDatePicker} label="营业期限" hasFeedback>
									{
										getFieldDecorator('bizDateMillis', {
											[data.bizStartDateMillis ? 'initialValue' : '']: [moment(data.bizStartDateMillis), moment(data.bizEndDateMillis)],
											rules                                          : [{
												type    : 'array',
												required: true,
												message : '请选择日期'
											}]
										})(
											<RangePicker style={style.datePicker}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='注册地址' hasFeedback>
									{
										getFieldDecorator('regAddr', {
											initialValue: data.regAddr,
											rules       : [
												{
													required: true,
													message : '请填写注册地址'
												},
												{
													type   : 'string',
													max    : 50,
													message: '注册地址 长度不能超过50'
												}
											]
										})(
											<Input placeholder="请输入注册地址"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='办公地址' hasFeedback>
									{
										getFieldDecorator('officeAddr', {
											initialValue: data.officeAddr,
											rules       : [
												{
													required: true,
													message : '请填写办公地址'
												},
												{
													type   : 'string',
													max    : 50,
													message: '办公地址 长度不能超过50'
												}
											]
										})(
											<Input placeholder="请输入办公地址"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='年营业额' hasFeedback>
									{
										getFieldDecorator('yearlyTurnover', {
											initialValue: data.yearlyTurnover,
											rules       : [
												{
													required: true,
													message : '请填写年营业额'
												},
												{
													type   : 'number',
													message: '请输入数字'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入年营业额" style={style.numInput}/>
										)
									}
									<span className="ant-form-text">万元</span>
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='注册资本' hasFeedback>
									{
										getFieldDecorator('regCapital', {
											initialValue: data.regCapital,
											rules       : [
												{
													required: true,
													message : '请填写注册资本'
												},
												{
													type   : 'number',
													message: '请输入数字'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入注册资本" style={style.numInput}/>
										)
									}
									<span className="ant-form-text">万元</span>
								</FormItem>
							</Col>
						</Row>
					</div>

					<RowTitle title="证件信息"/>

					<div className="form-wrap">
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否三证合一" className="ant-form-item-switch-required">
									{
										getFieldDecorator('threeInOneFlag', {
											valuePropName: 'checked',
											initialValue : data.threeInOneFlag == 1 ? 'checked' : '',
											onChange     : (value) => {
												// 设置联动表单的 error 值
												this.props.form.setFields({
													uniformCreditNo: {
														value: '',
														error: ''
													}
												});

												this.setState({
													isUniformCreditNoRequired: value
												});
											}
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="统一社会信用代码" hasFeedback>
									{
										getFieldDecorator('uniformCreditNo', {
											initialValue: data.uniformCreditNo,
											rules       : [
												{
													required: this.state.isUniformCreditNoRequired,
													message : '请填写社会信用代码'
												},
												{
													validator(rule, value, callback, source, options) {
														var errors = [];
														// 为空的时候不验证
														if (value != '' && !/^[A-Z0-9]+$/.test(value)) {
															errors.push(new Error('统一社会信用代码 只能填写大写字母或数字'));
														}

														callback(errors);
													}
												},
												{
													type   : 'string',
													max    : 18,
													message: '统一社会信用代码 长度不能超过18'
												}

											]
										})(
											<Input placeholder="请输入社会信用代码"/>
										)
									}
								</FormItem>
							</Col>
						</Row>
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="增值税一般纳税人资格" className="ant-form-item-switch-required">
									{
										getFieldDecorator('vatFlag', {
											valuePropName: 'checked',
											initialValue : data.vatFlag == 1 ? 'checked' : ''
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='营业执照编号'>
									{
										getFieldDecorator('licenceNo', {
											initialValue: data.licenceNo,
											rules       : [
												{
													type   : 'string',
													max    : 30,
													message: '营业执照编号 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入营业执照编号"/>
										)
									}
								</FormItem>
							</Col>
						</Row>
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='法定代表人' hasFeedback>
									{
										getFieldDecorator('legalAgent', {
											initialValue: data.legalAgent,
											rules       : [
												{
													required: true,
													message : '请填写法定代表人'
												},
												{
													type   : 'string',
													max    : 30,
													message: '法定代表人 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入法定代表人"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='证件类型' hasFeedback>
									{
										getFieldDecorator('credentialsType', {
											[data.credentialsType ? 'initialValue' : '']: data.credentialsType,
											rules                                       : [
												{ required: true, message: '请选择证件类型' }
											],
											onChange                                    : (value) => {
												// 设置联动表单的 error 值
												this.props.form.setFields({
													credentialsNo: {
														value: '',
														error: ''
													}
												});
											}
										})(
											<Select placeholder="请选择证件类型">
												{ CreateOption(CREDENTIALS_TYPE) }
											</Select>
										)
									}
								</FormItem>
							</Col>
						</Row>
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='证件号码' hasFeedback>
									{
										getFieldDecorator('credentialsNo', {
											initialValue: data.credentialsNo,
											rules       : [
												{
													required: true,
													message : '请填写证件号码'
												},
												{
													validator: (rule, value, callback, source, options)=> {
														var errors = [];
														if (this.props.form.getFieldValue('credentialsType') == 1) {
															if (!/^[0-9]{17,17}[0-9xX]$/.test(value)) {
																errors.push(new Error('请填写正确的证件号码'));
															}
														}
														callback(errors);
													}
												},
												{
													type   : 'string',
													max    : 30,
													message: '证件号码 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入证件号码"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>

							</Col>
						</Row>
					</div>

					<RowTitle title="运营能力"/>

					<div className="form-wrap">
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否有独立电商团队" className="ant-form-item-switch-required">
									{
										getFieldDecorator('eTeamFlag', {
											valuePropName: 'checked',
											initialValue : data.eTeamFlag == 1 ? 'checked' : '',
											onChange     : (value) => {
												// 设置联动表单的 error 值
												this.props.form.setFields({
													eTeamSize: {
														value: 0,
														error: ''
													}
												});

												this.setState({
													isETeamSizeDisabled: !value
												});

											}
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='团队人数'>
									{
										getFieldDecorator('eTeamSize', {
											initialValue: data.eTeamSize,
											rules       : [
												{
													type   : 'number',
													message: '请输入数字'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入团队人数" style={style.numInput} disabled={this.state.isETeamSizeDisabled}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否有独立运营网站" className="ant-form-item-switch-required">
									{
										getFieldDecorator('ownWebsiteFlag', {
											valuePropName: 'checked',
											initialValue : data.ownWebsiteFlag == 1 ? 'checked' : ''
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否有实体店" className="ant-form-item-switch-required">
									{
										getFieldDecorator('physicalStoreFlag', {
											valuePropName: 'checked',
											initialValue : data.physicalStoreFlag == 1 ? 'checked' : '',
											onChange     : (value) => {
												// 设置联动表单的 error 值
												this.props.form.setFields({
													headStoreAddr: {
														value: '',
														error: ''
													},
													storeDuration: {
														value: 0,
														error: ''
													}
												});

												this.setState({
													isPhysicalStoreFlagDisabled: !value
												});

											}
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='总店地址'>
									{
										getFieldDecorator('headStoreAddr', {
											initialValue: data.headStoreAddr,
											rules       : [
												{
													type   : 'string',
													max    : 30,
													message: '总店地址 长度不超过30'
												}
											]
										})(
											<Input placeholder="请输入总店地址" disabled={this.state.isPhysicalStoreFlagDisabled}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='实体店经营年限'>
									{
										getFieldDecorator('storeDuration', {
											initialValue: data.storeDuration - 0,
											rules       : [
												{
													type   : 'number',
													message: '请输入数字'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入实体店经营年限" style={style.numInput} disabled={this.state.isPhysicalStoreFlagDisabled}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否与其他平台合作" className="ant-form-item-switch-required">
									{
										getFieldDecorator('otherCoopFlag', {
											valuePropName: 'checked',
											initialValue : data.otherCoopFlag == 1 ? 'checked' : '',
											onChange     : (value) => {
												// 设置联动表单的 error 值
												this.props.form.setFields({
													coopPltName : {
														value: '',
														error: ''
													},
													monthSaleAmt: {
														value: 0,
														error: ''
													}
												});

												this.setState({
													isOtherCoopFlagDisabled: !value
												});

											}
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='合作平台名称'>
									{
										getFieldDecorator('coopPltName', {
											initialValue: data.coopPltName,
											rules       : [
												{
													type   : 'string',
													max    : 30,
													message: '合作平台名称 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入合作平台名称" disabled={this.state.isOtherCoopFlagDisabled}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='月均发单量'>
									{
										getFieldDecorator('monthSaleAmt', {
											initialValue: data.monthSaleAmt,
											rules       : [
												{
													type   : 'number',
													message: '请输入数字'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入月均发单量" style={style.numInput} disabled={this.state.isOtherCoopFlagDisabled}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>

							</Col>
						</Row>

					</div>

					<RowTitle title="服务能力"/>

					<div className="form-wrap">
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否可以配送" className="ant-form-item-switch-required">
									{
										getFieldDecorator('shipFlag', {
											valuePropName: 'checked',
											initialValue : data.shipFlag == 1 ? 'checked' : ''
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否有合作的物流" className="ant-form-item-switch-required">
									{
										getFieldDecorator('coopLogisticsFlag', {
											valuePropName: 'checked',
											initialValue : data.coopLogisticsFlag == 1 ? 'checked' : '',
											onChange     : (value) => {
												// 设置联动表单的 error 值
												this.props.form.setFields({
													coopLogisticsName: {
														value: '',
														error: ''
													}
												});

												this.setState({
													isCoopLogisticsFlagRequired: value
												});
											}
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='合作的物流名称' hasFeedback>
									{
										getFieldDecorator('coopLogisticsName', {
											initialValue: data.coopLogisticsName,
											rules       : [
												{
													required: this.state.isCoopLogisticsFlagRequired,
													message : '请填写合作物流名称'
												},
												{
													type   : 'string',
													max    : 50,
													message: '合作的物流名称 长度不能超过50'
												}
											]
										})(
											<Input placeholder="请输入合作的物流名称"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否自有仓库" className="ant-form-item-switch-required">
									{
										getFieldDecorator('ownWarehouseFlag', {
											valuePropName: 'checked',
											initialValue : data.ownWarehouseFlag == 1 ? 'checked' : '',
											onChange     : (value) => {

												this.props.form.setFields({
													uploadWarehousePhotos: {
														error: ''
													}
												});

												this.setState({
													isOwnWarehouseFlagRequired: value
												});

											}
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='仓库面积'>
									{
										getFieldDecorator('ownWarehouseArea', {
											initialValue: data.ownWarehouseArea,
											rules       : [
												{
													type   : 'integer',
													message: '输入数字必须是整数'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入仓库面积" style={style.numInput}/>
										)
									}
									<span className="ant-form-text">平方米</span>
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="节假日是否发货" className="ant-form-item-switch-required">
									{
										getFieldDecorator('holidayShipFlag', {
											valuePropName: 'checked',
											initialValue : data.holidayShipFlag == 1 ? 'checked' : ''
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'} style={style.switchWidth}/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='每日发货次数'>
									{
										getFieldDecorator('dailyShipTimes', {
											initialValue: data.dailyShipTimes,
											rules       : [
												{
													required: true,
													message : '请填写每日发货次数'
												},
												{
													type   : 'integer',
													message: '输入数字必须是整数'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入每日发货次数" style={style.numInput}/>
										)
									}
									<span className="ant-form-text">次</span>
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayoutNum} label='客服人数'>
									{
										getFieldDecorator('custServiceQty', {
											initialValue: data.custServiceQty,
											rules       : [
												{
													required: true,
													message : '请填写每日发货次数'
												},
												{
													type   : 'integer',
													message: '输入数字必须是整数'
												}
											]
										})(
											<InputNumber min={0} placeholder="请输入客服人数" style={style.numInput}/>
										)
									}
									<span className="ant-form-text">人</span>
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='热线电话'>
									{
										getFieldDecorator('hotline', {
											initialValue: data.hotline,
											rules       : [
												{
													required: true,
													message : '请填写热线电话'
												}
											]
										})(
											<Input min={0} placeholder="请输入热线电话"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>

								<FormItem  {...formItemLayoutDatePicker} label="工作日热线电话服务时间" className="ant-form-item-switch-required">
									<Col span="10">
										<FormItem>
											{
												getFieldDecorator('hotlineWorkdayStartMillis', {
													[data.hotlineWorkdayStartMillis ? 'initialValue' : '']: moment(data.hotlineWorkdayStartMillis),
													rules                                                 : [{
														type    : 'object',
														required: true,
														message : '请选择日期'
													}]
												})(
													// TODO.. 绑定提交的时候要看毫秒数
													<TimePicker format='HH:mm'/>
												)
											}
										</FormItem>
									</Col>
									<Col span="1" style={{marginRight:12,lineHeight:'28px'}}>
										<p className="ant-form-split">-</p>
									</Col>
									<Col span="10">
										<FormItem>
											{
												getFieldDecorator('hotlineWorkdayEndMillis', {
													[data.hotlineWorkdayEndMillis ? 'initialValue' : '']: moment(data.hotlineWorkdayEndMillis),
													rules                                               : [{
														type    : 'object',
														required: true,
														message : '请选择日期'
													}]
												})(
													<TimePicker format='HH:mm'/>
												)
											}
										</FormItem>
									</Col>
								</FormItem>

							</Col>
						</Row>


						<Row gutter={16}>
							<Col span={10} offset={1}>

								<FormItem  {...formItemLayoutDatePicker} label="周末及法定节假日热线电话服务时间" className="ant-form-item-switch-required">
									<Col span="10">
										<FormItem>
											{
												getFieldDecorator('hotlineWeekendStartMillis', {
													[data.hotlineWeekendStartMillis ? 'initialValue' : '']: moment(data.hotlineWeekendStartMillis),
													rules                                                 : [{
														type    : 'object',
														required: true,
														message : '请选择日期'
													}]
												})(
													<TimePicker format='HH:mm'/>
												)
											}
										</FormItem>
									</Col>
									<Col span="1" style={{marginRight:12,lineHeight:'28px'}}>
										<p className="ant-form-split">-</p>
									</Col>
									<Col span="10">
										<FormItem>
											{
												getFieldDecorator('hotlineWeekendEndMillis', {
													[data.hotlineWeekendEndMillis ? 'initialValue' : '']: moment(data.hotlineWeekendEndMillis),
													rules                                               : [{
														type    : 'object',
														required: true,
														message : '请选择日期'
													}]
												})(
													<TimePicker format='HH:mm'/>
												)
											}
										</FormItem>
									</Col>
								</FormItem>
							</Col>
							<Col span={10} offset={1}>

							</Col>
						</Row>

					</div>

					<RowTitle title="联系人"/>

					<div className="form-wrap">
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='业务联系人姓名' hasFeedback>
									{
										getFieldDecorator('bizConName', {
											initialValue: data.bizConName,
											rules       : [
												{
													required: true,
													message : '请填写业务联系人姓名'
												},
												{
													type   : 'string',
													max    : 30,
													message: '业务联系人姓名 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入业务联系人姓名"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='业务联系人固定电话' hasFeedback>
									{
										getFieldDecorator('bizConFixedPhone', {
											initialValue: data.bizConFixedPhone,
											rules       : [
												{
													required: true,
													message : '请填写业务联系人固定电话'
												},
												{
													type   : 'string',
													max    : 30,
													message: '业务联系人固定电话 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入业务联系人固定电话"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='业务联系人手机号' hasFeedback>
									{
										getFieldDecorator('bizConMobilePhone', {
											initialValue: data.bizConMobilePhone,
											rules       : [
												{
													required: true,
													message : '请填写业务联系人手机号'
												},
												{
													validator: (rule, value, callback, source, options)=> {
														var errors = [];
														if (!/^((1[0-9]{2})+\d{8})$/.test(value)) {
															errors.push(new Error('请填写正确的手机号'));
														}
														callback(errors);
													}
												},
												{
													type   : 'string',
													max    : 30,
													message: '业务联系人手机号 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入业务联系人手机号"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='业务联系人邮箱' hasFeedback>
									{
										getFieldDecorator('bizConEmail', {
											initialValue: data.bizConEmail,
											rules       : [
												{
													required: true,
													message : '请填写业务联系人邮箱'
												},
												{
													type   : 'email',
													message: '请输入正确的邮箱'
												},
												{
													type   : 'string',
													max    : 60,
													message: '业务联系人邮箱 长度不能超过60'
												}
											]
										})(
											<Input placeholder="请输入业务联系人邮箱"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='财务联系人姓名' hasFeedback>
									{
										getFieldDecorator('finConName', {
											initialValue: data.finConName,
											rules       : [
												{
													required: true,
													message : '请填写业财务联系人姓名'
												},
												{
													type   : 'string',
													max    : 30,
													message: '财务联系人姓名 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入财务联系人姓名"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='财务联系人固定电话' hasFeedback>
									{
										getFieldDecorator('finConFixedPhone', {
											initialValue: data.finConFixedPhone,
											rules       : [
												{
													required: true,
													message : '请填写财务联系人固定电话'
												},
												{
													type   : 'string',
													max    : 30,
													message: '财务联系人固定电话 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入财务联系人固定电话"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='财务联系人手机号' hasFeedback>
									{
										getFieldDecorator('finConMobilePhone', {
											initialValue: data.finConMobilePhone,
											rules       : [
												{
													required: true,
													message : '请填写财务联系人手机号'
												},
												{
													validator: (rule, value, callback, source, options)=> {
														var errors = [];
														if (!/^((1[0-9]{2})+\d{8})$/.test(value)) {
															errors.push(new Error('请填写正确的手机号'));
														}
														callback(errors);
													}
												},
												{
													type   : 'string',
													max    : 30,
													message: '财务联系人手机号 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入财务联系人手机号"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='财务联系人邮箱' hasFeedback>
									{
										getFieldDecorator('finConEmail', {
											initialValue: data.finConEmail,
											rules       : [
												{
													required: true,
													message : '请填写财务联系人邮箱'
												},
												{
													type   : 'email',
													message: '请输入正确的邮箱'
												},
												{
													type   : 'string',
													max    : 60,
													message: '财务联系人邮箱 长度不能超过60'
												}
											]
										})(
											<Input placeholder="请输入财务联系人邮箱"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='客服联系人姓名' hasFeedback>
									{
										getFieldDecorator('custConName', {
											initialValue: data.custConName,
											rules       : [
												{
													required: true,
													message : '请填写客服联系人姓名'
												},
												{
													type   : 'string',
													max    : 30,
													message: '客服联系人姓名 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入客服联系人姓名"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='客服联系人固定电话' hasFeedback>
									{
										getFieldDecorator('custConFixedPhone', {
											initialValue: data.custConFixedPhone,
											rules       : [
												{
													required: true,
													message : '请填写客服联系人固定电话'
												},
												{
													type   : 'string',
													max    : 30,
													message: '客服联系人固定电话 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入客服联系人固定电话"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='客服联系人手机号' hasFeedback>
									{
										getFieldDecorator('custConMobilePhone', {
											initialValue: data.custConMobilePhone,
											rules       : [
												{
													required: true,
													message : '请填写客服联系人手机号'
												},
												{
													validator: (rule, value, callback, source, options)=> {
														var errors = [];
														if (!/^((1[0-9]{2})+\d{8})$/.test(value)) {
															errors.push(new Error('请填写正确的手机号'));
														}
														callback(errors);
													}
												},
												{
													type   : 'string',
													max    : 30,
													message: '客服联系人手机号 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入客服联系人手机号"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='客服联系人邮箱' hasFeedback>
									{
										getFieldDecorator('custConEmail', {
											initialValue: data.custConEmail,
											rules       : [
												{
													required: true,
													message : '请填写客服联系人邮箱'
												},
												{
													type   : 'email',
													message: '请输入正确的邮箱'
												},
												{
													type   : 'string',
													max    : 60,
													message: '客服联系人邮箱 长度不能超过60'
												}
											]
										})(
											<Input placeholder="请输入客服联系人邮箱"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

					</div>

					<RowTitle title="财务清算"/>

					<div className="form-wrap">
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='收款账号名称' hasFeedback>
									{
										getFieldDecorator('bankAcctName', {
											initialValue: data.bankAcctName,
											rules       : [
												{
													required: true,
													message : '请填写收款账号名称'
												},
												{
													type   : 'string',
													max    : 30,
													message: '收款账号名称 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入收款账号名称"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='收款账号' hasFeedback>
									{
										getFieldDecorator('bankAcctNo', {
											initialValue: data.bankAcctNo,
											rules       : [
												{
													required: true,
													message : '请填写收款账号'
												},
												{
													type   : 'string',
													max    : 30,
													message: '收款账号 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入收款账号"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='开户银行名称' hasFeedback>
									{
										getFieldDecorator('bankName', {
											initialValue: data.bankName,
											rules       : [
												{
													required: true,
													message : '请填写开户银行名称'
												},
												{
													type   : 'string',
													max    : 50,
													message: '开户银行名称 长度不能超过50'
												}
											]
										})(
											<Input placeholder="请输入开户银行名称"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='联行行号'>
									{
										getFieldDecorator('bankCode', {
											initialValue: data.bankCode,
											rules       : [
												{
													type   : 'string',
													max    : 30,
													message: '联行行号 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入联行行号"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='银行所在地' hasFeedback>
									{
										getFieldDecorator('bankLocCity', {
											initialValue: data.bankLocCity,
											rules       : [
												{
													required: true,
													message : '请填写银行所在地'
												},
												{
													type   : 'string',
													max    : 30,
													message: '银行所在地 城市 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入银行所在地"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='清算币种' hasFeedback>
									{
										getFieldDecorator('settleCurrency', {
											[data.settleCurrency ? 'initialValue' : '']: data.settleCurrency,
											rules                                      : [
												{ required: true, message: '请选择清算币种' }
											]
										})(
											<Select placeholder="请选择清算币种">
												{ CreateOption(CURRENCY_TYPE) }
											</Select>
										)}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="是否需要增值税专用发票" className="ant-form-item-switch-required">
									{
										getFieldDecorator('vatInvoiceFlag', {
											valuePropName: 'checked',
											initialValue : data.vatInvoiceFlag == 1 ? 'checked' : ''
										})(
											<Switch checkedChildren={'是'} unCheckedChildren={'否'}/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='纳税人名称' hasFeedback>
									{
										getFieldDecorator('taxPayerName', {
											initialValue: data.taxPayerName,
											rules       : [
												{
													required: true,
													message : '请填写纳税人名称'
												},
												{
													type   : 'string',
													max    : 30,
													message: '纳税人名称 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入纳税人名称"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='纳税人地址' hasFeedback>
									{
										getFieldDecorator('taxAddr', {
											initialValue: data.taxAddr,
											rules       : [
												{
													required: true,
													message : '请填写纳税人地址'
												},
												{
													type   : 'string',
													max    : 50,
													message: '纳税人地址 长度不能超过50'
												}
											]
										})(
											<Input placeholder="请输入纳税人地址"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='纳税人识别号' hasFeedback>
									{
										getFieldDecorator('taxPayerNo', {
											initialValue: data.taxPayerNo,
											rules       : [
												{
													required: true,
													message : '请填写纳税人识别号'
												},
												{
													validator: (rule, value, callback, source, options)=> {
														var errors = [];
														if (!/^[A-Za-z0-9]{15,18}$/.test(value)) {
															errors.push(new Error('请填写正确的纳税人识别号'));
														}
														callback(errors);
													}
												}

											]
										})(
											<Input placeholder="请输入纳税人识别号"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='接受发票的地址' hasFeedback>
									{
										getFieldDecorator('acptInvoiceAddr', {
											initialValue: data.acptInvoiceAddr,
											rules       : [
												{
													required: true,
													message : '请填写接受发票的地址'
												},
												{
													type   : 'string',
													max    : 50,
													message: '接受发票的地址 长度不能超过50'
												}
											]
										})(
											<Input placeholder="请输入接受发票的地址"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='增值税发票银行开户行名称' hasFeedback>
									{
										getFieldDecorator('acptBankName', {
											initialValue: data.acptBankName,
											rules       : [
												{
													required: true,
													message : '请填写增值税发票银行开户行名称'
												},
												{
													type   : 'string',
													max    : 50,
													message: '增值税发票银行开户行名称 长度不能超过50'
												}
											]
										})(
											<Input placeholder="请输入增值税发票银行开户行名称"/>
										)
									}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label='增值税发票银行开户行账号' hasFeedback>
									{
										getFieldDecorator('acptBankAcctNo', {
											initialValue: data.acptBankAcctNo,
											rules       : [
												{
													required: true,
													message : '请填写增值税银行开户行账号'
												},
												{
													type   : 'string',
													max    : 30,
													message: '增值税银行开户行账号 长度不能超过30'
												}
											]
										})(
											<Input placeholder="请输入增值税银行开户行账号"/>
										)
									}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>

							</Col>
						</Row>

					</div>

					<div className="form-wrap">
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="营业执照">
									{getFieldDecorator('uploadLicence', {
										initialValue: this.state.fileListLicence,
										rules       : [
											{
												required: true,
												message : '请上传营业执照'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListLicence} onChange={(file)=>{
											this.uploadChange(file,"fileListLicence");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="现金流量表">
									{getFieldDecorator('uploadCashFlowStatement', {
										initialValue: this.state.fileListCashFlowStatement,
										rules       : [
											{
												required: true,
												message : '请上传现金流量表'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListCashFlowStatement} onChange={(file)=>{
											this.uploadChange(file,"fileListCashFlowStatement");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="法定代表人证件">
									{getFieldDecorator('uploadLegalCert', {
										initialValue: this.state.fileListLegalCert,
										rules       : [
											{
												required: true,
												message : '请上传法定代表人证件'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListLegalCert} onChange={(file)=>{
											this.uploadChange(file,"fileListLegalCert");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="品牌授权委托书">
									{getFieldDecorator('uploadBrandAuthor', {
										initialValue: this.state.fileListBrandAuthor,
										rules       : [
											{
												required: true,
												message : '请上传品牌授权委托书'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListBrandAuthor} onChange={(file)=>{
											this.uploadChange(file,"fileListBrandAuthor");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="资产负债表">
									{getFieldDecorator('uploadBalanceSheet', {
										initialValue: this.state.fileListBalanceSheet,
										rules       : [
											{
												required: true,
												message : '请上传资产负债表'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListBalanceSheet} onChange={(file)=>{
											this.uploadChange(file,"fileListBalanceSheet");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="损益表或验资报告">
									{getFieldDecorator('uploadIncomeStatement', {
										initialValue: this.state.fileListIncomeStatement,
										rules       : [
											{
												required: true,
												message : '请上传损益表或验资报告'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListIncomeStatement} onChange={(file)=>{
											this.uploadChange(file,"fileListIncomeStatement");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
						</Row>

						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="仓库照片">
									{getFieldDecorator('uploadWarehousePhotos', {
										initialValue: this.state.fileListWarehousePhotos,
										rules       : [
											{
												required: this.state.isOwnWarehouseFlagRequired,
												message : '请上传仓库照片'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListWarehousePhotos} onChange={(file)=>{
											this.uploadChange(file,"fileListWarehousePhotos");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="办公地址照片">
									{getFieldDecorator('uploadOfficeAddressPhoto', {
										initialValue: this.state.fileListOfficeAddressPhoto,
										rules       : [
											{
												required: true,
												message : '请上传办公地址照片'
											}
										]
									})(
										<Upload {...propsUpload} fileList={this.state.fileListOfficeAddressPhoto} onChange={(file)=>{
											this.uploadChange(file,"fileListOfficeAddressPhoto");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
						</Row>
						<Row gutter={16}>
							<Col span={10} offset={1}>
								<FormItem {...formItemLayout} label="其他">
									{getFieldDecorator('uploadOthers', {
										initialValue: this.state.fileListOthers
									})(
										<Upload {...propsUpload} fileList={this.state.fileListOthers} onChange={(file)=>{
											this.uploadChange(file,"fileListOthers");
										}}>
											<Button icon="upload">
												文件上传
											</Button>
										</Upload>
									)}
								</FormItem>
							</Col>
							<Col span={10} offset={1}>

							</Col>
						</Row>

					</div>
				
					<div className="form-btn-wrap" style={{display:data.state==2?'none':'block'}}>
						<Row gutter={16}>
							<Col offset={20}>
								<Button type="primary" htmlType="submit">
									保存并提交审核
								</Button>
							</Col>
						</Row>
					</div>

				</Form>
			</div>
		)
	}
}


const mapStateToProps = (state) => {

	const { error, vendorData } = state.vendor;
	const { userData } = state.user;

	return {
		error,
		vendorData,
		userData
	};

};

export default connect(mapStateToProps)(Form.create()(Edit));
